@@ -6,8 +6,6 @@
 * Copyright (c) 2006 Sean Finney <seanius@seanius.net>
 * Copyright (c) 2006-2008 Nagios Plugins Development Team
 * 
-* Last Modified: $Date: 2008-09-01 15:04:22 +0100 (Mon, 01 Sep 2008) $
-* 
 * Description:
 * 
 * This file contains the check_ntp_time plugin
@@ -33,12 +31,10 @@
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 * 
-* $Id: check_ntp_time.c 2051 2008-09-01 14:04:22Z dermoth $
 * 
 *****************************************************************************/
 
 const char *progname = "check_ntp_time";
-const char *revision = "$Revision: 2051 $";
 const char *copyright = "2006-2008";
 const char *email = "nagiosplug-devel@lists.sourceforge.net";
 
@@ -81,7 +77,7 @@ typedef struct {
 
 /* this structure holds data about results from querying offset from a peer */
 typedef struct {
-	time_t waiting;         /* ts set when we started waiting for a response */ 
+	time_t waiting;         /* ts set when we started waiting for a response */
 	int num_responses;      /* number of successfully recieved responses */
 	uint8_t stratum;        /* copied verbatim from the ntp_message */
 	double rtdelay;         /* converted from the ntp_message */
@@ -132,7 +128,7 @@ typedef struct {
  they are divided into halves, each being a 16-bit int in network byte order:
  - the first 16 bits are an int on the left side of a decimal point.
  - the second 16 bits represent a fraction n/(2^16)
- likewise for the 64-bit "fixed point" numbers with everything doubled :) 
+ likewise for the 64-bit "fixed point" numbers with everything doubled :)
  **/
 
 /* macros to access the left/right 16 bits of a 32-bit ntp "fixed point"
@@ -299,7 +295,7 @@ int best_offset_server(const ntp_server_results *slist, int nservers){
 
 /* do everything we need to get the total average offset
  * - we use a certain amount of parallelization with poll() to ensure
- *   we don't waste time sitting around waiting for single packets. 
+ *   we don't waste time sitting around waiting for single packets.
  * - we also "manually" handle resolving host names and connecting, because
  *   we have to do it in a way that our lazy macros don't handle currently :( */
 double offset_request(const char *host, int *status){
@@ -461,7 +457,7 @@ int process_arguments(int argc, char **argv){
 		{0, 0, 0, 0}
 	};
 
-	
+
 	if (argc < 2)
 		usage ("\n");
 
@@ -476,7 +472,7 @@ int process_arguments(int argc, char **argv){
 			exit(STATE_OK);
 			break;
 		case 'V':
-			print_revision(progname, revision);
+			print_revision(progname, NP_VERSION);
 			exit(STATE_OK);
 			break;
 		case 'v':
@@ -594,7 +590,7 @@ int main(int argc, char *argv[]){
 }
 
 void print_help(void){
-	print_revision(progname, revision);
+	print_revision(progname, NP_VERSION);
 
 	printf ("Copyright (c) 2006 Sean Finney\n");
 	printf (COPYRIGHT, copyright, email);
@@ -604,17 +600,17 @@ void print_help(void){
 	printf ("\n\n");
 
 	print_usage();
-	printf (_(UT_HELP_VRSN));
-	printf (_(UT_EXTRA_OPTS));
-	printf (_(UT_HOST_PORT), 'p', "123");
+	printf (UT_HELP_VRSN);
+	printf (UT_EXTRA_OPTS);
+	printf (UT_HOST_PORT, 'p', "123");
 	printf (" %s\n", "-q, --quiet");
 	printf ("    %s\n", _("Returns UNKNOWN instead of CRITICAL if offset cannot be found"));
 	printf (" %s\n", "-w, --warning=THRESHOLD");
 	printf ("    %s\n", _("Offset to result in warning status (seconds)"));
 	printf (" %s\n", "-c, --critical=THRESHOLD");
 	printf ("    %s\n", _("Offset to result in critical status (seconds)"));
-	printf (_(UT_TIMEOUT), DEFAULT_SOCKET_TIMEOUT);
-	printf (_(UT_VERBOSE));
+	printf (UT_TIMEOUT, DEFAULT_SOCKET_TIMEOUT);
+	printf (UT_VERBOSE);
 
 	printf("\n");
 	printf("%s\n", _("This plugin checks the clock offset between the local host and a"));
@@ -626,23 +622,19 @@ void print_help(void){
 	printf(" %s\n", _("If you'd rather want to monitor an NTP server, please use"));
 	printf(" %s\n", _("check_ntp_peer."));
 	printf("\n");
-	printf(_(UT_THRESHOLDS_NOTES));
-#ifdef NP_EXTRA_OPTS
-	printf("\n");
-	printf(_(UT_EXTRA_OPTS_NOTES));
-#endif
+	printf(UT_THRESHOLDS_NOTES);
 
 	printf("\n");
 	printf("%s\n", _("Examples:"));
 	printf("  %s\n", ("./check_ntp_time -H ntpserv -w 0.5 -c 1"));
 
-	printf (_(UT_SUPPORT));
+	printf (UT_SUPPORT);
 }
 
 void
 print_usage(void)
 {
-	printf (_("Usage:"));
+	printf ("%s\n", _("Usage:"));
 	printf(" %s -H <host> [-w <warn>] [-c <crit>] [-v verbose]\n", progname);
 }
 
