@@ -141,6 +141,7 @@ int calculate_rate = 0;
 int rate_multiplier = 1;
 state_data *previous_state;
 double previous_value[MAX_OIDS];
+int perf_labels = 1;
 
 
 int
@@ -169,7 +170,7 @@ main (int argc, char **argv)
 	char *state_string=NULL;
 	size_t response_length, current_length, string_length;
 	char *temp_string=NULL;
-	int is_numeric=0;
+	char *quote_string=NULL;
 	time_t current_time;
 	double temp_double;
 	time_t duration;
@@ -335,29 +336,24 @@ main (int argc, char **argv)
 		/* We strip out the datatype indicator for PHBs */
 		if (strstr (response, "Gauge: ")) {
 			show = strstr (response, "Gauge: ") + 7;
-			is_numeric++;
 		} 
 		else if (strstr (response, "Gauge32: ")) {
 			show = strstr (response, "Gauge32: ") + 9;
-			is_numeric++;
 		} 
 		else if (strstr (response, "Counter32: ")) {
 			show = strstr (response, "Counter32: ") + 11;
-			is_numeric++;
 			is_counter=1;
 			if(!calculate_rate) 
 				strcpy(type, "c");
 		}
 		else if (strstr (response, "Counter64: ")) {
 			show = strstr (response, "Counter64: ") + 11;
-			is_numeric++;
 			is_counter=1;
 			if(!calculate_rate)
 				strcpy(type, "c");
 		}
 		else if (strstr (response, "INTEGER: ")) {
 			show = strstr (response, "INTEGER: ") + 9;
-			is_numeric++;
 		}
 		else if (strstr (response, "STRING: ")) {
 			show = strstr (response, "STRING: ") + 8;
@@ -396,15 +392,17 @@ main (int argc, char **argv)
 			}
 
 		}
-		else if (strstr (response, "Timeticks: "))
+		else if (strstr (response, "Timeticks: ")) {
 			show = strstr (response, "Timeticks: ");
+		}
 		else
 			show = response;
 
 		iresult = STATE_DEPENDENT;
 
 		/* Process this block for numeric comparisons */
-		 if (is_numeric) {
+		/* Make some special values,like Timeticks numeric only if a threshold is defined */
+		if (thlds[i]->warning || thlds[i]->critical || calculate_rate) {
 			ptr = strpbrk (show, "0123456789");
 			if (ptr == NULL)
 				die (STATE_UNKNOWN,_("No valid data returned"));
@@ -489,11 +487,22 @@ main (int argc, char **argv)
 		ptr = NULL;
 		strtod(show, &ptr);
 		if (ptr > show) {
-			if (nlabels >= (size_t)1 && (size_t)i < nlabels && labels[i] != NULL)
+			if (perf_labels && nlabels >= (size_t)1 && (size_t)i < nlabels && labels[i] != NULL)
 				temp_string=labels[i];
 			else
 				temp_string=oidname;
-			strncat(perfstr, temp_string, sizeof(perfstr)-strlen(perfstr)-1);
+			if (strpbrk (temp_string, " ='\"") == NULL) {
+				strncat(perfstr, temp_string, sizeof(perfstr)-strlen(perfstr)-1);
+			} else {
+				if (strpbrk (temp_string, "'") == NULL) {
+					quote_string="'";
+				} else {
+					quote_string="\"";
+				}
+				strncat(perfstr, quote_string, sizeof(perfstr)-strlen(perfstr)-1);
+				strncat(perfstr, temp_string, sizeof(perfstr)-strlen(perfstr)-1);
+				strncat(perfstr, quote_string, sizeof(perfstr)-strlen(perfstr)-1);
+			}
 			strncat(perfstr, "=", sizeof(perfstr)-strlen(perfstr)-1);
 			len = sizeof(perfstr)-strlen(perfstr)-1;
 			strncat(perfstr, show, len>ptr-show ? ptr-show : len);
@@ -587,6 +596,7 @@ process_arguments (int argc, char **argv)
 		{"rate", no_argument, 0, L_CALCULATE_RATE},
 		{"rate-multiplier", required_argument, 0, L_RATE_MULTIPLIER},
 		{"invert-search", no_argument, 0, L_INVERT_SEARCH},
+		{"perf-oids", no_argument, 0, 'O'},
 		{0, 0, 0, 0}
 	};
 
@@ -604,7 +614,7 @@ process_arguments (int argc, char **argv)
 	}
 
 	while (1) {
-		c = getopt_long (argc, argv, "nhvVt:c:w:H:C:o:e:E:d:D:s:t:R:r:l:u:p:m:P:L:U:a:x:A:X:",
+		c = getopt_long (argc, argv, "nhvVOt:c:w:H:C:o:e:E:d:D:s:t:R:r:l:u:p:m:P:L:U:a:x:A:X:",
 									 longopts, &option);
 
 		if (c == -1 || c == EOF)
@@ -744,7 +754,7 @@ process_arguments (int argc, char **argv)
 			labels[nlabels - 1] = optarg;
 			ptr = thisarg (optarg);
 			labels[nlabels - 1] = ptr;
-			if (strstr (ptr, "'") == ptr)
+			if (ptr[0] == '\'')
 				labels[nlabels - 1] = ptr + 1;
 			while (ptr && (ptr = nextarg (ptr))) {
 				if (nlabels >= labels_size) {
@@ -753,9 +763,9 @@ process_arguments (int argc, char **argv)
 					if (labels == NULL)
 						die (STATE_UNKNOWN, _("Could not reallocate labels\n"));
 				}
-				labels++;
+				nlabels++;
 				ptr = thisarg (ptr);
-				if (strstr (ptr, "'") == ptr)
+				if (ptr[0] == '\'')
 					labels[nlabels - 1] = ptr + 1;
 				else
 					labels[nlabels - 1] = ptr;
@@ -773,7 +783,7 @@ process_arguments (int argc, char **argv)
 			unitv[nunits - 1] = optarg;
 			ptr = thisarg (optarg);
 			unitv[nunits - 1] = ptr;
-			if (strstr (ptr, "'") == ptr)
+			if (ptr[0] == '\'')
 				unitv[nunits - 1] = ptr + 1;
 			while (ptr && (ptr = nextarg (ptr))) {
 				if (nunits >= unitv_size) {
@@ -784,7 +794,7 @@ process_arguments (int argc, char **argv)
 				}
 				nunits++;
 				ptr = thisarg (ptr);
-				if (strstr (ptr, "'") == ptr)
+				if (ptr[0] == '\'')
 					unitv[nunits - 1] = ptr + 1;
 				else
 					unitv[nunits - 1] = ptr;
@@ -802,6 +812,9 @@ process_arguments (int argc, char **argv)
 		case L_INVERT_SEARCH:
 			invert_search=1;
 			break;
+		case 'O':
+			perf_labels=0;
+			break;
 		}
 	}
 
@@ -939,7 +952,7 @@ char *
 thisarg (char *str)
 {
 	str += strspn (str, " \t\r\n");	/* trim any leading whitespace */
-	if (strstr (str, "'") == str) {	/* handle SIMPLE quoted strings */
+	if (str[0] == '\'') {	/* handle SIMPLE quoted strings */
 		if (strlen (str) == 1 || !strstr (str + 1, "'"))
 			die (STATE_UNKNOWN, _("Unbalanced quotes\n"));
 	}
@@ -955,7 +968,7 @@ thisarg (char *str)
 char *
 nextarg (char *str)
 {
-	if (strstr (str, "'") == str) {
+	if (str[0] == '\'') {
 		str[0] = 0;
 		if (strlen (str) > 1) {
 			str = strstr (str + 1, "'");
@@ -965,7 +978,7 @@ nextarg (char *str)
 			return NULL;
 		}
 	}
-	if (strstr (str, ",") == str) {
+	if (str[0] == ',') {
 		str[0] = 0;
 		if (strlen (str) > 1) {
 			return (++str);
@@ -1067,6 +1080,9 @@ print_help (void)
 	printf (" %s\n", "-e, --retries=INTEGER");
 	printf ("    %s\n", _("Number of retries to be used in the requests"));
 
+	printf (" %s\n", "-O, --perf-oids");
+	printf ("    %s\n", _("Label performance data with OIDs instead of --label's"));
+
 	printf (UT_VERBOSE);
 
 	printf ("\n");
@@ -1076,8 +1092,8 @@ print_help (void)
 
 	printf ("\n");
 	printf ("%s\n", _("Notes:"));
-	printf (" %s\n", _("- Multiple OIDs may be indicated by a comma or space-delimited list (lists with"));
-	printf ("   %s %i %s\n", _("internal spaces must be quoted). Maximum:"), MAX_OIDS, _("OIDs."));
+	printf (" %s\n", _("- Multiple OIDs (and labels) may be indicated by a comma or space-delimited  "));
+	printf ("   %s %i %s\n", _("list (lists with internal spaces must be quoted). Maximum:"), MAX_OIDS, _("OIDs."));
 
 	printf(" -%s", UT_THRESHOLDS_NOTES);
 
