@@ -611,10 +611,10 @@ print_help (void)
 
 	print_usage ();
 
-	printf (_(UT_HELP_VRSN));
-	printf (_(UT_EXTRA_OPTS));
+	printf (UT_HELP_VRSN);
+	printf (UT_EXTRA_OPTS);
 
-	printf (_(UT_HOST_PORT), 'p', myport);
+	printf (UT_HOST_PORT, 'p', myport);
 
 	printf (" %s\n", "-u, --ups=STRING");
   printf ("    %s\n", _("Name of UPS"));
@@ -623,13 +623,13 @@ print_help (void)
   printf (" %s\n", "-v, --variable=STRING");
   printf ("    %s %s\n", _("Valid values for STRING are"), "LINE, TEMP, BATTPCT or LOADPCT");
 
-	printf (_(UT_WARN_CRIT));
+	printf (UT_WARN_CRIT);
 
-	printf (_(UT_TIMEOUT), DEFAULT_SOCKET_TIMEOUT);
+	printf (UT_TIMEOUT, DEFAULT_SOCKET_TIMEOUT);
 
 /* TODO: -v clashing with -v/-variable. Commenting out help text since verbose
          is unused up to now */
-/*	printf (_(UT_VERBOSE)); */
+/*	printf (UT_VERBOSE); */
 
   printf ("\n");
 	printf ("%s\n", _("This plugin attempts to determine the status of a UPS (Uninterruptible Power"));
@@ -649,18 +649,14 @@ print_help (void)
   printf (" %s\n", _("Network UPS Tools be installed on the remote host. If you do not have the"));
   printf (" %s\n", _("package installed on your system, you can download it from"));
   printf (" %s\n", _("http://www.networkupstools.org"));
-#ifdef NP_EXTRA_OPTS
-  printf ("\n");
-  printf (_(UT_EXTRA_OPTS_NOTES));
-#endif
 
-	printf (_(UT_SUPPORT));
+	printf (UT_SUPPORT);
 }
 
 
 void
 print_usage (void)
 {
-  printf (_("Usage:"));
+  printf ("%s\n", _("Usage:"));
 	printf ("%s -H host -u ups [-p port] [-v variable] [-w warn_value] [-c crit_value] [-to to_sec] [-T]\n", progname);
 }
