@@ -59,6 +59,12 @@
 #include <math.h>
 #endif
 
+#ifdef _AIX
+#ifdef HAVE_MP_H
+#include <mp.h>
+#endif
+#endif
+
 #ifdef HAVE_STRINGS_H
 #include <strings.h>
 #endif
